@@ -1264,7 +1264,17 @@ class Sf:
         Extra Notes and Examples of Usage
         """
         sfRTDF = pd.DataFrame(self.sf.query_all("SELECT "+ ",".join(fieldAPINames) + " from RecordType WHERE SobjectType = '" + objectAPIName + "'")['records'])
-        sfRTDF.drop(columns="attributes", inplace = True)
+        
+        # If only master RT exists
+        if len(sfRTDF) == 0:
+            master_rt = {
+                "Name": "Master",
+                "DeveloperName": "Master"
+            }
+
+            sfRTDF = pd.DataFrame(master_rt, index=[0])
+        else:
+            sfRTDF.drop(columns="attributes", inplace = True)
         return sfRTDF
 
     def object_permission_check(self, object, permission):
